# from __future__ import annotations

from pydantic import Field, AnyUrl
from typing import Optional, Union, Any, List

# dynamic registering
from .definitions import register_model, model_dependence

# basic definitions
from .definitions import Date, DateTime, Text


# base imports
from .series import Series


@register_model
class CreativeWorkSeries(Series):
    """A CreativeWorkSeries in schema org is a group of related items typically but not necessarily of the same kind CreativeWorkSeries are usually organized into some order often chronological Unlike ItemList which is a general purpose data structure for lists of things the emphasis with CreativeWorkSeries is on published materials written e g books and periodicals or media such as TV radio and games Specific subtypes are available for describing TVSeries RadioSeries MovieSeries BookSeries Periodical and VideoGameSeries In each case the hasPart isPartOf properties can be used to relate the CreativeWorkSeries to its parts The general CreativeWorkSeries type serves largely just to organize these more specific and practical subtypes It is common for properties applicable to an item from the series to be usefully applied to the containing group Schema org attempts to anticipate some of these cases but publishers should be free to apply properties of the series parts to the series as a whole wherever they seem appropriate"""

    endDate: Optional[Union[str, List[str]]] = Field(
        None, description="The end date and time of the item in ISO 8601 date format"
    )
    issn: Optional[Union[str, List[str]]] = Field(
        None,
        description="The International Standard Serial Number ISSN that identifies this serial publication You can repeat this property to identify different formats of or the linking ISSN ISSN L for this serial publication",
    )
    startDate: Optional[Union[str, List[str]]] = Field(
        None, description="The start date and time of the item in ISO 8601 date format"
    )


# parent dependences
model_dependence("CreativeWorkSeries", "Series")


# attribute dependences
model_dependence(
    "CreativeWorkSeries",
)
